@@ -29,6 +29,12 @@ TDNFAllocateMemory(
     void** ppMemory
     );
 
+uint32_t
+TDNFReAllocateMemory(
+    size_t nSize,
+    void** ppMemory
+    );
+
 uint32_t
 TDNFAllocateString(
     const char* pszSrc,
@@ -244,6 +250,10 @@ TDNFStringMatchesOneOf(
     char **ppszList,
     int *pRet);
 
+uint32_t
+TDNFJoinPath(
+    char **ppszPath, ...);
+
 //setopt.c
 uint32_t
 AddSetOpt(
